==> qtjambi-nfc-5.15.3-sources.jar: io/qt/nfc/QNdefRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC NDEF record</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qndefrecord.html">QNdefRecord</a></p>
 */
public class QNdefRecord extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qndefrecord.html#TypeNameFormat-enum">QNdefRecord::TypeNameFormat</a></p>
     */
    public enum TypeNameFormat implements io.qt.QtEnumerator {
        Empty(0),
        NfcRtd(1),
        Mime(2),
        Uri(3),
        ExternalRtd(4),
        Unknown(5);

        private TypeNameFormat(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static TypeNameFormat resolve(int value) {
            switch (value) {
            case 0: return Empty;
            case 1: return NfcRtd;
            case 2: return Mime;
            case 3: return Uri;
            case 4: return ExternalRtd;
            case 5: return Unknown;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#QNdefRecord">QNdefRecord::QNdefRecord()</a></p>
     */
    public QNdefRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefRecord instance);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type){
        super((QPrivateConstructor)null);
        initialize_native(this, typeNameFormat, type);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#QNdefRecord-1">QNdefRecord::QNdefRecord(QNdefRecord)</a></p>
     */
    public QNdefRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat){
        super((QPrivateConstructor)null);
        initialize_native(this, other, typeNameFormat);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type){
        super((QPrivateConstructor)null);
        initialize_native(this, other, typeNameFormat, type);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#id">QNdefRecord::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#isEmpty">QNdefRecord::isEmpty()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#operator-eq-eq">QNdefRecord::operator==(QNdefRecord)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.nfc.QNdefRecord other){
        return operator_equal_native_cref_QNdefRecord_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QNdefRecord_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#payload">QNdefRecord::payload()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray payload(){
        return payload_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray payload_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setId">QNdefRecord::setId(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setId(io.qt.core.QByteArray id){
        setId_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @io.qt.QtUninvokable
    private native void setId_native_cref_QByteArray(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setPayload">QNdefRecord::setPayload(QByteArray)</a></p>
     */
    @io.qt.QtDeclaredFinal
    @io.qt.QtUninvokable
    public void setPayload(io.qt.core.QByteArray payload){
        setPayload_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(payload));
    }
    
    @io.qt.QtUninvokable
    private native void setPayload_native_cref_QByteArray(long __this__nativeId, long payload);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setType">QNdefRecord::setType(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setType(io.qt.core.QByteArray type){
        setType_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(type));
    }
    
    @io.qt.QtUninvokable
    private native void setType_native_cref_QByteArray(long __this__nativeId, long type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setTypeNameFormat">QNdefRecord::setTypeNameFormat(QNdefRecord::TypeNameFormat)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setTypeNameFormat(io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat){
        setTypeNameFormat_native_QNdefRecord_TypeNameFormat(QtJambi_LibraryUtilities.internal.nativeId(this), typeNameFormat.value());
    }
    
    @io.qt.QtUninvokable
    private native void setTypeNameFormat_native_QNdefRecord_TypeNameFormat(long __this__nativeId, int typeNameFormat);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#type">QNdefRecord::type()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray type(){
        return type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray type_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#typeNameFormat">QNdefRecord::typeNameFormat()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat(){
        return io.qt.nfc.QNdefRecord.TypeNameFormat.resolve(typeNameFormat_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int typeNameFormat_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefRecord(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.nfc.QNdefRecord) {
            return operator_equal((io.qt.nfc.QNdefRecord) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QNdefRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-5.15.13-sources.jar: io/qt/nfc/QNdefRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC NDEF record</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qndefrecord.html">QNdefRecord</a></p>
 */
public class QNdefRecord extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qndefrecord.html#TypeNameFormat-enum">QNdefRecord::TypeNameFormat</a></p>
     */
    public enum TypeNameFormat implements io.qt.QtEnumerator {
        Empty(0),
        NfcRtd(1),
        Mime(2),
        Uri(3),
        ExternalRtd(4),
        Unknown(5);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private TypeNameFormat(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static TypeNameFormat resolve(int value) {
            switch (value) {
            case 0: return Empty;
            case 1: return NfcRtd;
            case 2: return Mime;
            case 3: return Uri;
            case 4: return ExternalRtd;
            case 5: return Unknown;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#QNdefRecord">QNdefRecord::QNdefRecord()</a></p>
     */
    public QNdefRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefRecord instance);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type){
        super((QPrivateConstructor)null);
        initialize_native(this, typeNameFormat, type);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#QNdefRecord-1">QNdefRecord::QNdefRecord(QNdefRecord)</a></p>
     */
    public QNdefRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat){
        super((QPrivateConstructor)null);
        initialize_native(this, other, typeNameFormat);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat);
    
    protected QNdefRecord(io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type){
        super((QPrivateConstructor)null);
        initialize_native(this, other, typeNameFormat, type);
    }
    
    private native static void initialize_native(QNdefRecord instance, io.qt.nfc.QNdefRecord other, io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat, io.qt.core.QByteArray type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#id">QNdefRecord::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#isEmpty">QNdefRecord::isEmpty()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#operator-eq-eq">QNdefRecord::operator==(QNdefRecord)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.nfc.QNdefRecord other){
        return operator_equal_native_cref_QNdefRecord_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QNdefRecord_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#payload">QNdefRecord::payload()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray payload(){
        return payload_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray payload_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setId">QNdefRecord::setId(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setId(io.qt.core.QByteArray id){
        setId_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @io.qt.QtUninvokable
    private native void setId_native_cref_QByteArray(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setPayload">QNdefRecord::setPayload(QByteArray)</a></p>
     */
    @io.qt.QtDeclaredFinal
    @io.qt.QtUninvokable
    public void setPayload(io.qt.core.QByteArray payload){
        setPayload_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(payload));
    }
    
    @io.qt.QtUninvokable
    private native void setPayload_native_cref_QByteArray(long __this__nativeId, long payload);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setType">QNdefRecord::setType(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setType(io.qt.core.QByteArray type){
        setType_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(type));
    }
    
    @io.qt.QtUninvokable
    private native void setType_native_cref_QByteArray(long __this__nativeId, long type);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#setTypeNameFormat">QNdefRecord::setTypeNameFormat(QNdefRecord::TypeNameFormat)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setTypeNameFormat(io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat){
        setTypeNameFormat_native_QNdefRecord_TypeNameFormat(QtJambi_LibraryUtilities.internal.nativeId(this), typeNameFormat.value());
    }
    
    @io.qt.QtUninvokable
    private native void setTypeNameFormat_native_QNdefRecord_TypeNameFormat(long __this__nativeId, int typeNameFormat);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#type">QNdefRecord::type()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray type(){
        return type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray type_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefrecord.html#typeNameFormat">QNdefRecord::typeNameFormat()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.nfc.QNdefRecord.TypeNameFormat typeNameFormat(){
        return io.qt.nfc.QNdefRecord.TypeNameFormat.resolve(typeNameFormat_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int typeNameFormat_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefRecord(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.nfc.QNdefRecord) {
            return operator_equal((io.qt.nfc.QNdefRecord) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QNdefRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefRecord clone_native(long __this_nativeId);
}
